@@ -59,18 +59,8 @@ class Client:
         self,
         network: Network,
         insecure: bool = False,
-        credentials: grpc.ChannelCredentials = None,
+        credentials = grpc.ssl_channel_credentials()
     ):
-        # load root CA cert
-        if not insecure:
-            if network.env == 'testnet':
-                if credentials is None:
-                    with open(os.path.join(os.path.dirname(__file__), 'cert/testnet.crt'), 'rb') as f:
-                        credentials = grpc.ssl_channel_credentials(f.read())
-            if network.env == 'mainnet':
-                if credentials is None:
-                    with open(os.path.join(os.path.dirname(__file__), 'cert/mainnet.crt'), 'rb') as f:
-                        credentials = grpc.ssl_channel_credentials(f.read())
 
         # chain stubs
         self.chain_channel = (
